@@ -48,7 +48,7 @@ impl Config {
         Ok(home
             .join(".config")
             .join(crate_name)
-            .join(&format!("{}.toml", crate_name)))
+            .join(&format!("{crate_name}.toml")))
     }
 
     /// Gets the custom config file path specified by the `PACAPTR_CONFIG`
@@ -60,7 +60,7 @@ impl Config {
     fn custom_path() -> Result<PathBuf> {
         env::var(CONFIG_ENV_VAR)
             .map_err(|e| Error::ConfigError {
-                msg: format!("Config path environment variable not found: {}", e),
+                msg: format!("Config path environment variable not found: {e}"),
             })
             .map(PathBuf::from)
     }
@@ -76,13 +76,12 @@ impl Config {
     /// # Errors
     /// Returns an [`Error::ConfigError`] when the config file loading fails.
     pub(crate) fn try_load() -> Result<Self> {
-        let path = Config::custom_path().or_else(|_| Config::default_path())?;
-        path.exists()
-            .then(|| confy::load_path(&path))
-            .transpose()
-            .map_err(|_e| Error::ConfigError {
-                msg: format!("Failed to read config at `{:?}`", &path),
-            })
-            .map(Option::unwrap_or_default)
+        let path = Self::custom_path().or_else(|_e| Self::default_path())?;
+        if !path.exists() {
+            return Ok(Self::default());
+        }
+        confy::load_path(&path).map_err(|_e| Error::ConfigError {
+            msg: format!("Failed to read config at `{:?}`", &path),
+        })
     }
 }
