@@ -26,7 +26,7 @@ impl Unknown {
     /// Creates a new [`Unknown`] package manager with the given name.
     pub(crate) fn new(name: &str) -> Self {
         Unknown {
-            name: format!("unknown package manager: {}", name),
+            name: format!("unknown package manager: {name}"),
             cfg: Config::default(),
         }
     }
